import type { AxiosInstance } from 'axios';
import type { FeatType } from '/@/projectCom/assets/equipment/pchart/types';
import request from '/@/utils/request';

/**
 * @summary GetAssetsEquipmentPhartMappingExtensionsByEquipmentID
 */
export const GetAssetsEquipmentPhartMappingExtensionsByEquipmentID = (params, req: AxiosInstance = request) => {
	return req({
		url: '/Assets/Equipment/Phart/Mapping/Extensions/GetByEquipmentID@V1.0',
		method: 'get',
		params,
	});
};

/**
 * @summary 添加一个设备图表映射(extensions)
 */
export const InsertAAssetsEquipmentPhartMappingExtensions = async (data, req: any = request) => {
	return req({
		url: '/Assets/Equipment/Phart/Mapping/Extensions/Insert@V1.0',
		method: 'post',
		data,
	});
};

/**
 * @summary 修改一个设备图表映射(extensions)
 */
export const UpdateAAssetsEquipmentPhartMappingExtensions = async (data, req: any = request) => {
	return req({
		url: '/Assets/Equipment/Phart/Mapping/Extensions/Update@V1.0',
		method: 'put',
		data,
	});
};

/**
 * @summary 删除一个设备图表映射(extensions)
 */
export const DeleteAAssetsEquipmentPhartMappingExtensions = async (params, req: any = request) => {
	return req({
		url: '/Assets/Equipment/Phart/Mapping/Extensions/DeleteByDiagramID@V1.0',
		method: 'delete',
		params,
	});
};

export interface ChartGraph {
	ID: string;
	DiagramID: string;
	Name: string;
	GraphType: number;
	GraphParas: {
		Hz: number;
		N: number;
	};
	GraphInfo: string;
	GeometryStyle: number;
	GeometryParas: {
		FeatType: FeatType;
	};
	GeometryInfo: string;
	DispParas: string;
	ExtraParas: string;
	Paras?: Record<string, unknown>;
	Flags: Record<string, unknown>[];
	SortCode: number;
	Description: string;
}
export type ChartGraphInsert = Omit<PhartDiagram, 'ID' | 'SortCode'>;

export interface PhartDiagram {
	ID: string;
	Name: string;
	NO: string;
	DiagramType: number;
	DiagramParas: string;
	DiagramInfo: string;
	DispParas: string;
	ExtraParas: string;
	Paras?: Record<string, unknown>;
	Flags: Record<string, unknown>[];
	TagName: string;
	SortCode: number;
	Description: string;
	GraphList: ChartGraph[];
}

export type PhartDiagramInsert = Omit<PhartDiagram, 'ID' | 'SortCode'> & {
	GraphList: ChartGraphInsert[];
};

export type EquipPhartMapping = {
	ID: string;
	EquipmentID: string;
	DiagramID: string;
	OtherName: string;
	Importance: number;
	SortCode: number;
	Diagram: PhartDiagram;
};

export type EquipPhartMappingInsert = Omit<EquipPhartMapping, 'ID' | 'SortCode'> & {
	Diagram: PhartDiagramInsert;
};
